var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/amap/Viewport.ts
var Viewport_exports = {};
__export(Viewport_exports, {
  default: () => Viewport
});
module.exports = __toCommonJS(Viewport_exports);
var import_gl_matrix = require("gl-matrix");
var DEGREES_TO_RADIANS = Math.PI / 180;
var Viewport = class {
  constructor() {
    this.projectionMatrix = import_gl_matrix.mat4.create();
    this.viewMatrix = import_gl_matrix.mat4.create();
    this.viewProjectionMatrix = import_gl_matrix.mat4.create();
    this.ViewProjectionMatrixUncentered = import_gl_matrix.mat4.create();
    this.viewUncenteredMatrix = import_gl_matrix.mat4.create();
  }
  syncWithMapCamera(mapCamera) {
    const {
      zoom = 1,
      pitch = 0,
      bearing = 0,
      center = [0, 0],
      offsetOrigin = [0, 0],
      cameraHeight = 1,
      aspect = 1,
      near = 0.1,
      far = 1e3,
      fov = 0
    } = mapCamera;
    this.zoom = zoom;
    this.center = center;
    const pitchInRadians = pitch * DEGREES_TO_RADIANS;
    const rotationInRadians = (360 - bearing) * DEGREES_TO_RADIANS;
    import_gl_matrix.mat4.perspective(this.projectionMatrix, fov, aspect, near, far);
    const eye = import_gl_matrix.vec3.fromValues(cameraHeight * Math.sin(pitchInRadians) * Math.sin(rotationInRadians), -cameraHeight * Math.sin(pitchInRadians) * Math.cos(rotationInRadians), cameraHeight * Math.cos(pitchInRadians));
    const up = import_gl_matrix.vec3.fromValues(-Math.cos(pitchInRadians) * Math.sin(rotationInRadians), Math.cos(pitchInRadians) * Math.cos(rotationInRadians), Math.sin(pitchInRadians));
    import_gl_matrix.mat4.lookAt(this.viewMatrix, eye, import_gl_matrix.vec3.fromValues(0, 0, 0), up);
    this.viewUncenteredMatrix = import_gl_matrix.mat4.clone(this.viewMatrix);
    import_gl_matrix.mat4.translate(this.viewMatrix, this.viewMatrix, import_gl_matrix.vec3.fromValues(-offsetOrigin[0], offsetOrigin[1], 0));
    import_gl_matrix.mat4.multiply(this.viewProjectionMatrix, this.projectionMatrix, this.viewMatrix);
    import_gl_matrix.mat4.multiply(this.ViewProjectionMatrixUncentered, this.projectionMatrix, this.viewMatrix);
  }
  getZoom() {
    return this.zoom;
  }
  getZoomScale() {
    return 524288;
  }
  getCenter() {
    const [lng, lat] = this.center;
    return [lng, lat];
  }
  getProjectionMatrix() {
    return this.projectionMatrix;
  }
  getModelMatrix() {
    return [1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1, 0, 0, 0, 0, 1];
  }
  getViewMatrix() {
    return this.viewMatrix;
  }
  getViewMatrixUncentered() {
    return this.viewUncenteredMatrix;
  }
  getViewProjectionMatrix() {
    return this.viewProjectionMatrix;
  }
  getViewProjectionMatrixUncentered() {
    return this.ViewProjectionMatrixUncentered;
  }
  getFocalDistance() {
    return 1;
  }
  projectFlat(lngLat) {
    const maxs = 85.0511287798;
    const lat = Math.max(Math.min(maxs, lngLat[1]), -maxs);
    const zoomScale = 256 << 20;
    let d = Math.PI / 180;
    let x = lngLat[0] * d;
    let y = lat * d;
    y = Math.log(Math.tan(Math.PI / 4 + y / 2));
    const a = 0.5 / Math.PI;
    const b = 0.5;
    const c = -0.5 / Math.PI;
    d = 0.5;
    x = zoomScale * (a * x + b) - 215440491;
    y = -(zoomScale * (c * y + d) - 106744817);
    return [x, y];
  }
};
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {});
