var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target, mod));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var __decorateClass = (decorators, target, key, kind) => {
  var result = kind > 1 ? void 0 : kind ? __getOwnPropDesc(target, key) : target;
  for (var i = decorators.length - 1, decorator; i >= 0; i--)
    if (decorator = decorators[i])
      result = (kind ? decorator(target, key, result) : decorator(result)) || result;
  if (kind && result)
    __defProp(target, key, result);
  return result;
};

// src/earth/map.ts
var map_exports = {};
__export(map_exports, {
  default: () => L7EarthService
});
module.exports = __toCommonJS(map_exports);
var import_l7_core = require("@antv/l7-core");
var import_l7_map = require("@antv/l7-map");
var import_inversify = require("inversify");
var import_reflect_metadata = require("reflect-metadata");
var import_version = require("../version");
var import_Viewport = __toESM(require("./Viewport"));
var import_BaseMapService = __toESM(require("../utils/BaseMapService"));
var EventMap = {
  mapmove: "move",
  camerachange: "move",
  zoomchange: "zoom",
  dragging: "drag"
};
var LNGLAT_OFFSET_ZOOM_THRESHOLD = 12;
var L7EarthService = class extends import_BaseMapService.default {
  constructor() {
    super(...arguments);
    this.version = import_version.Version.GLOBEL;
    this.dragging = false;
    this.handleCameraChanged = (e) => {
      this.emit("mapchange");
      const DELAY_TIME = 2e3;
      this.handleCameraChanging = true;
      if (this.handleCameraTimer) {
        clearTimeout(this.handleCameraTimer);
      }
      this.handleCameraTimer = setTimeout(() => {
        this.handleCameraChanging = false;
      }, DELAY_TIME);
      const rotateStep = 0.02;
      if (e.type && e.originalEvent) {
        if (e.originalEvent.type === "wheel") {
          this.viewport.scaleZoom(0.01 * Math.sign(e.originalEvent.wheelDelta) * -1);
        }
        if (Math.abs(e.originalEvent.movementX) > Math.abs(e.originalEvent.movementY)) {
          if (e.originalEvent.movementX > 0) {
            this.viewport.rotateY(rotateStep);
          } else if (e.originalEvent.movementX < 0) {
            this.viewport.rotateY(-rotateStep);
          }
        } else {
          if (e.originalEvent.movementY > 0) {
            this.viewport.rotateX(rotateStep);
          } else if (e.originalEvent.movementY < 0) {
            this.viewport.rotateX(-rotateStep);
          }
        }
      }
      const { offsetCoordinate = true } = this.config;
      this.viewport.syncWithMapCamera({
        viewportHeight: this.map.transform.height,
        viewportWidth: this.map.transform.width
      });
      if (this.viewport.getZoom() > LNGLAT_OFFSET_ZOOM_THRESHOLD && offsetCoordinate) {
        this.coordinateSystemService.setCoordinateSystem(import_l7_core.CoordinateSystem.LNGLAT_OFFSET);
      } else {
        this.coordinateSystemService.setCoordinateSystem(import_l7_core.CoordinateSystem.LNGLAT);
      }
      this.cameraChangedCallback(this.viewport);
    };
  }
  lngLatToMercator(lnglat, altitude) {
    throw new Error("Method not implemented.");
  }
  getModelMatrix(lnglat, altitude, rotate, scale, origin) {
    throw new Error("Method not implemented.");
  }
  on(type, handle) {
    if (import_l7_core.MapServiceEvent.indexOf(type) !== -1) {
      this.eventEmitter.on(type, handle);
    } else {
      this.map.on(EventMap[type] || type, handle);
    }
  }
  off(type, handle) {
    this.map.off(EventMap[type] || type, handle);
    this.eventEmitter.off(type, handle);
  }
  getMapCanvasContainer() {
    return this.map.getCanvasContainer();
  }
  getSize() {
    const size = this.map.transform;
    return [size.width, size.height];
  }
  getType() {
    return "earth";
  }
  async init() {
    const { id = "map", style = "light", rotation = 0, ...rest } = this.config;
    this.viewport = new import_Viewport.default();
    this.$mapContainer = this.creatMapContainer(id);
    this.map = new import_l7_map.EarthMap({
      container: this.$mapContainer,
      style: this.getMapStyle(style),
      bearing: rotation,
      ...rest
    });
    this.map.on("load", this.handleCameraChanged);
    this.map.on("move", this.handleCameraChanged);
    this.handleCameraChanged({});
  }
  destroy() {
    var _a, _b;
    (_b = (_a = this.$mapContainer) == null ? void 0 : _a.parentNode) == null ? void 0 : _b.removeChild(this.$mapContainer);
    this.eventEmitter.removeAllListeners();
    if (this.map) {
      this.map.remove();
      this.$mapContainer = null;
    }
  }
  emit(name, ...args) {
    this.eventEmitter.emit(name, ...args);
  }
  once(name, ...args) {
    this.eventEmitter.once(name, ...args);
  }
  getMapContainer() {
    return this.$mapContainer;
  }
  onCameraChanged(callback) {
    this.cameraChangedCallback = callback;
  }
  rotateY(option) {
    const { force = false, reg = 0.01 } = option || {};
    if (this.handleCameraChanging && !force) {
      return;
    }
    if (this.viewport) {
      this.viewport.rotateY(reg);
      this.viewport.syncWithMapCamera({
        viewportHeight: this.map.transform.height,
        viewportWidth: this.map.transform.width
      });
      this.cameraChangedCallback(this.viewport);
    }
  }
};
L7EarthService = __decorateClass([
  (0, import_inversify.injectable)()
], L7EarthService);
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {});
