var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target, mod));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var __decorateClass = (decorators, target, key, kind) => {
  var result = kind > 1 ? void 0 : kind ? __getOwnPropDesc(target, key) : target;
  for (var i = decorators.length - 1, decorator; i >= 0; i--)
    if (decorator = decorators[i])
      result = (kind ? decorator(target, key, result) : decorator(result)) || result;
  if (kind && result)
    __defProp(target, key, result);
  return result;
};

// src/mapbox/map.ts
var map_exports = {};
__export(map_exports, {
  default: () => MapboxService
});
module.exports = __toCommonJS(map_exports);
var import_gl_matrix = require("gl-matrix");
var import_inversify = require("inversify");
var import_mapbox_gl = __toESM(require("mapbox-gl"));
var import_version = require("../version");
var import_mapbox_gl2 = require("mapbox-gl/dist/mapbox-gl.css");
var import_reflect_metadata = require("reflect-metadata");
var import_Viewport = __toESM(require("./Viewport"));
var import_BaseMapService = __toESM(require("../utils/BaseMapService"));
window.mapboxgl = import_mapbox_gl.default;
var mapdivCount = 0;
var MAPBOX_API_KEY = "pk.eyJ1IjoiMTg5Njk5NDg2MTkiLCJhIjoiY2s5OXVzdHlzMDVneDNscDVjdzVmeXl0dyJ9.81SQ5qaJS0xExYLbDZAGpQ";
var MapboxService = class extends import_BaseMapService.default {
  constructor() {
    super(...arguments);
    this.version = import_version.Version.MAPBOX;
  }
  getType() {
    return "mapbox";
  }
  lngLatToCoord(lnglat, origin = { x: 0, y: 0, z: 0 }) {
    const { x, y } = this.lngLatToMercator(lnglat, 0);
    return [x - origin.x, y - origin.y];
  }
  lngLatToMercator(lnglat, altitude) {
    const {
      x = 0,
      y = 0,
      z = 0
    } = window.mapboxgl.MercatorCoordinate.fromLngLat(lnglat, altitude);
    return { x, y, z };
  }
  getModelMatrix(lnglat, altitude, rotate, scale = [1, 1, 1], origin = { x: 0, y: 0, z: 0 }) {
    const modelAsMercatorCoordinate = window.mapboxgl.MercatorCoordinate.fromLngLat(lnglat, altitude);
    const meters = modelAsMercatorCoordinate.meterInMercatorCoordinateUnits();
    const modelMatrix = import_gl_matrix.mat4.create();
    import_gl_matrix.mat4.translate(modelMatrix, modelMatrix, import_gl_matrix.vec3.fromValues(modelAsMercatorCoordinate.x - origin.x, modelAsMercatorCoordinate.y - origin.y, modelAsMercatorCoordinate.z || 0 - origin.z));
    import_gl_matrix.mat4.scale(modelMatrix, modelMatrix, import_gl_matrix.vec3.fromValues(meters * scale[0], -meters * scale[1], meters * scale[2]));
    import_gl_matrix.mat4.rotateX(modelMatrix, modelMatrix, rotate[0]);
    import_gl_matrix.mat4.rotateY(modelMatrix, modelMatrix, rotate[1]);
    import_gl_matrix.mat4.rotateZ(modelMatrix, modelMatrix, rotate[2]);
    return modelMatrix;
  }
  async init() {
    const {
      id = "map",
      attributionControl = false,
      style = "light",
      token = MAPBOX_API_KEY,
      rotation = 0,
      mapInstance,
      ...rest
    } = this.config;
    this.viewport = new import_Viewport.default();
    if (!mapInstance && !window.mapboxgl) {
      console.error(this.configService.getSceneWarninfo("SDK"));
    }
    if (token === MAPBOX_API_KEY && style !== "blank" && !window.mapboxgl.accessToken && !mapInstance) {
      console.warn(this.configService.getSceneWarninfo("MapToken"));
    }
    if (!mapInstance && !window.mapboxgl.accessToken) {
      window.mapboxgl.accessToken = token;
    }
    if (mapInstance) {
      this.map = mapInstance;
      this.$mapContainer = this.map.getContainer();
    } else {
      this.$mapContainer = this.creatMapContainer(id);
      this.map = new window.mapboxgl.Map({
        container: this.$mapContainer,
        style: this.getMapStyle(style),
        attributionControl,
        bearing: rotation,
        ...rest
      });
    }
    this.map.on("load", this.handleCameraChanged);
    this.map.on("move", this.handleCameraChanged);
    this.handleCameraChanged();
  }
  destroy() {
    var _a, _b;
    (_b = (_a = this.$mapContainer) == null ? void 0 : _a.parentNode) == null ? void 0 : _b.removeChild(this.$mapContainer);
    this.eventEmitter.removeAllListeners();
    if (this.map) {
      this.map.remove();
      this.$mapContainer = null;
    }
  }
  emit(name, ...args) {
    this.eventEmitter.emit(name, ...args);
  }
  once(name, ...args) {
    this.eventEmitter.once(name, ...args);
  }
  getMapContainer() {
    return this.$mapContainer;
  }
  meterToCoord(center, outer) {
    const centerLnglat = new import_mapbox_gl.default.LngLat(center[0], center[1]);
    const outerLnglat = new import_mapbox_gl.default.LngLat(outer[0], outer[1]);
    const meterDis = centerLnglat.distanceTo(outerLnglat);
    const centerMercator = import_mapbox_gl.default.MercatorCoordinate.fromLngLat({
      lng: center[0],
      lat: center[1]
    });
    const outerMercator = import_mapbox_gl.default.MercatorCoordinate.fromLngLat({
      lng: outer[0],
      lat: outer[1]
    });
    const { x: x1, y: y1 } = centerMercator;
    const { x: x2, y: y2 } = outerMercator;
    const coordDis = Math.sqrt(Math.pow(x1 - x2, 2) + Math.pow(y1 - y2, 2)) * 4194304 * 2;
    return coordDis / meterDis;
  }
  exportMap(type) {
    const renderCanvas = this.map.getCanvas();
    const layersPng = type === "jpg" ? renderCanvas == null ? void 0 : renderCanvas.toDataURL("image/jpeg") : renderCanvas == null ? void 0 : renderCanvas.toDataURL("image/png");
    return layersPng;
  }
  creatMapContainer(id) {
    let $wrapper = id;
    if (typeof id === "string") {
      $wrapper = document.getElementById(id);
    }
    const $amapdiv = document.createElement("div");
    $amapdiv.style.cssText += `
      position: absolute;
      top: 0;
      height: 100%;
      width: 100%;
    `;
    $amapdiv.id = "l7_mapbox_div" + mapdivCount++;
    $wrapper.appendChild($amapdiv);
    return $amapdiv;
  }
};
MapboxService = __decorateClass([
  (0, import_inversify.injectable)()
], MapboxService);
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {});
