var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var __decorateClass = (decorators, target, key, kind) => {
  var result = kind > 1 ? void 0 : kind ? __getOwnPropDesc(target, key) : target;
  for (var i = decorators.length - 1, decorator; i >= 0; i--)
    if (decorator = decorators[i])
      result = (kind ? decorator(target, key, result) : decorator(result)) || result;
  if (kind && result)
    __defProp(target, key, result);
  return result;
};

// src/utils/BaseMapService.ts
var BaseMapService_exports = {};
__export(BaseMapService_exports, {
  default: () => BaseMapService
});
module.exports = __toCommonJS(BaseMapService_exports);
var import_l7_core = require("@antv/l7-core");
var import_l7_utils = require("@antv/l7-utils");
var import_inversify = require("inversify");
var import_reflect_metadata = require("reflect-metadata");
var import_simpleMapCoord = require("./simpleMapCoord");
var import_version = require("../version");
var import_theme = require("./theme");
var EventMap = {
  mapmove: "move",
  camerachange: "move",
  zoomchange: "zoom",
  dragging: "drag"
};
var LNGLAT_OFFSET_ZOOM_THRESHOLD = 12;
var BaseMapService = class {
  constructor() {
    this.version = import_version.Version.L7MAP;
    this.simpleMapCoord = new import_simpleMapCoord.SimpleMapCoord();
    this.bgColor = "rgba(0.0, 0.0, 0.0, 0.0)";
    this.handleCameraChanged = (e) => {
      const { lat, lng } = this.map.getCenter();
      this.emit("mapchange");
      this.viewport.syncWithMapCamera({
        bearing: this.map.getBearing(),
        center: [lng, lat],
        viewportHeight: this.map.transform.height,
        pitch: this.map.getPitch(),
        viewportWidth: this.map.transform.width,
        zoom: this.map.getZoom(),
        cameraHeight: 0
      });
      this.updateCoordinateSystemService();
      this.cameraChangedCallback(this.viewport);
    };
  }
  setBgColor(color) {
    this.bgColor = color;
  }
  addMarkerContainer() {
    const container = this.map.getCanvasContainer();
    this.markerContainer = import_l7_utils.DOM.create("div", "l7-marker-container", container);
    this.markerContainer.setAttribute("tabindex", "-1");
  }
  getMarkerContainer() {
    return this.markerContainer;
  }
  getOverlayContainer() {
    return void 0;
  }
  on(type, handle) {
    if (import_l7_core.MapServiceEvent.indexOf(type) !== -1) {
      this.eventEmitter.on(type, handle);
    } else {
      this.map.on(EventMap[type] || type, handle);
    }
  }
  off(type, handle) {
    this.map.off(EventMap[type] || type, handle);
    this.eventEmitter.off(type, handle);
  }
  getContainer() {
    return this.map.getContainer();
  }
  getMapCanvasContainer() {
    return this.map.getCanvasContainer();
  }
  getSize() {
    if (this.version === import_version.Version.SIMPLE) {
      return this.simpleMapCoord.getSize();
    }
    const size = this.map.transform;
    return [size.width, size.height];
  }
  getType() {
    return "default";
  }
  getZoom() {
    return this.map.getZoom();
  }
  setZoom(zoom) {
    return this.map.setZoom(zoom);
  }
  getCenter() {
    return this.map.getCenter();
  }
  setCenter(lnglat) {
    this.map.setCenter(lnglat);
  }
  getPitch() {
    return this.map.getPitch();
  }
  getRotation() {
    return this.map.getBearing();
  }
  getBounds() {
    return this.map.getBounds().toArray();
  }
  getMinZoom() {
    return this.map.getMinZoom();
  }
  getMaxZoom() {
    return this.map.getMaxZoom();
  }
  setRotation(rotation) {
    this.map.setBearing(rotation);
  }
  zoomIn(option, eventData) {
    this.map.zoomIn(option, eventData);
  }
  zoomOut(option, eventData) {
    this.map.zoomOut(option, eventData);
  }
  setPitch(pitch) {
    return this.map.setPitch(pitch);
  }
  panTo(p) {
    this.map.panTo(p);
  }
  panBy(x = 0, y = 0) {
    this.panTo([x, y]);
  }
  fitBounds(bound, fitBoundsOptions) {
    this.map.fitBounds(bound, fitBoundsOptions);
  }
  setMaxZoom(max) {
    this.map.setMaxZoom(max);
  }
  setMinZoom(min) {
    this.map.setMinZoom(min);
  }
  setMapStatus(option) {
    if (option.doubleClickZoom === true) {
      this.map.doubleClickZoom.enable();
    }
    if (option.doubleClickZoom === false) {
      this.map.doubleClickZoom.disable();
    }
    if (option.dragEnable === false) {
      this.map.dragPan.disable();
    }
    if (option.dragEnable === true) {
      this.map.dragPan.enable();
    }
    if (option.rotateEnable === false) {
      this.map.dragRotate.disable();
    }
    if (option.dragEnable === true) {
      this.map.dragRotate.enable();
    }
    if (option.keyboardEnable === false) {
      this.map.keyboard.disable();
    }
    if (option.keyboardEnable === true) {
      this.map.keyboard.enable();
    }
    if (option.zoomEnable === false) {
      this.map.scrollZoom.disable();
    }
    if (option.zoomEnable === true) {
      this.map.scrollZoom.enable();
    }
  }
  setZoomAndCenter(zoom, center) {
    this.map.flyTo({
      zoom,
      center
    });
  }
  setMapStyle(style) {
    this.map.setStyle(this.getMapStyle(style));
  }
  meterToCoord(center, outer) {
    return 1;
  }
  pixelToLngLat(pixel) {
    return this.map.unproject(pixel);
  }
  lngLatToPixel(lnglat) {
    return this.map.project(lnglat);
  }
  containerToLngLat(pixel) {
    return this.map.unproject(pixel);
  }
  lngLatToContainer(lnglat) {
    return this.map.project(lnglat);
  }
  destroy() {
    this.eventEmitter.removeAllListeners();
    if (this.map) {
      this.map.remove();
      this.$mapContainer = null;
    }
  }
  emit(name, ...args) {
    this.eventEmitter.emit(name, ...args);
  }
  once(name, ...args) {
    this.eventEmitter.once(name, ...args);
  }
  getMapContainer() {
    return this.$mapContainer;
  }
  exportMap(type) {
    const renderCanvas = this.map.getCanvas();
    const layersPng = type === "jpg" ? renderCanvas == null ? void 0 : renderCanvas.toDataURL("image/jpeg") : renderCanvas == null ? void 0 : renderCanvas.toDataURL("image/png");
    return layersPng;
  }
  onCameraChanged(callback) {
    this.cameraChangedCallback = callback;
  }
  creatMapContainer(id) {
    let $wrapper = id;
    if (typeof id === "string") {
      $wrapper = document.getElementById(id);
    }
    return $wrapper;
  }
  updateView(viewOption) {
    this.emit("mapchange");
    this.viewport.syncWithMapCamera({
      bearing: viewOption.bearing,
      center: viewOption.center,
      viewportHeight: viewOption.viewportHeight,
      pitch: viewOption.pitch,
      viewportWidth: viewOption.viewportWidth,
      zoom: viewOption.zoom,
      cameraHeight: 0
    });
    this.updateCoordinateSystemService();
    this.cameraChangedCallback(this.viewport);
  }
  updateCoordinateSystemService() {
    const { offsetCoordinate = true } = this.config;
    if (this.viewport.getZoom() > LNGLAT_OFFSET_ZOOM_THRESHOLD && offsetCoordinate) {
      this.coordinateSystemService.setCoordinateSystem(import_l7_core.CoordinateSystem.LNGLAT_OFFSET);
    } else {
      this.coordinateSystemService.setCoordinateSystem(import_l7_core.CoordinateSystem.LNGLAT);
    }
  }
  getMapStyle(name) {
    if (typeof name !== "string") {
      return name;
    }
    return import_theme.MapTheme[name] ? import_theme.MapTheme[name] : name;
  }
};
__decorateClass([
  (0, import_inversify.inject)(import_l7_core.TYPES.MapConfig)
], BaseMapService.prototype, "config", 2);
__decorateClass([
  (0, import_inversify.inject)(import_l7_core.TYPES.IGlobalConfigService)
], BaseMapService.prototype, "configService", 2);
__decorateClass([
  (0, import_inversify.inject)(import_l7_core.TYPES.ICoordinateSystemService)
], BaseMapService.prototype, "coordinateSystemService", 2);
__decorateClass([
  (0, import_inversify.inject)(import_l7_core.TYPES.IEventEmitter)
], BaseMapService.prototype, "eventEmitter", 2);
BaseMapService = __decorateClass([
  (0, import_inversify.injectable)()
], BaseMapService);
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {});
